atmcmc-package:
Automatically Tuned Markov Chain Monte Carlo
Description
This package tunes a symmetric random walk Metropolis algorithm with Gaussian proposals via finite MCMC adaption combined with new adaptive diagnostics, and it runs the tuned algorithm to converge to a target distribution and estimate the stationary mean of a functional.
Details
|
Package: |
| atmcmc |
|
Type: |
| Package |
|
Version: |
| 1.0 |
|
Date: |
| 2014-09-16 |
|
License: |
| GPL (>= 2) |
The main function is `atmcmc', which is to run a MCMC algorithm with adaptive schemes and diagnostics embedded. `plotmcmc' function is to get traceplots and histograms of output from an `atmcmc' run. `summarymcmc' function displays summary statistics from the output.
References
Jinyoung Yang and Jeffrey S. Rosenthal. Automatically Tuned General-Purpose MCMC via New Convergence Diagnostics. Preprint, 2014.